@@ -2,23 +2,18 @@ import os
 import re
 import socket
 
-from mysqld_integration_test.log import logger
+BASEDIRS = ['/', '/usr', '/usr/local', '/opt/homebrew']
 
-BASEDIRS = ['/', '/usr', '/usr/local']
 
 class Utils():
-
     @staticmethod
-    def find_program(name, subdirs):
-        for basedir in BASEDIRS:
-            for subdir in subdirs:
-                path = os.path.join(basedir, subdir, name)
-                logger.debug(f"Searching for {name} in {path}")
+    def find_program(name):
+        for basedir in ['usr', 'usr/local']:
+            for subdir in ['bin', 'libexec', 'sbin', 'scripts']:
+                path = os.path.join("/", basedir, subdir, name)
                 if os.path.exists(path):
                     return path
-
-        raise RuntimeError(f"Command not found: {name}")
-
+        return None
 
     @staticmethod
     def get_unused_port():
@@ -35,7 +30,6 @@ class Utils():
         version_major = int(version_info[0][0])
         version_minor = version_info[0][1]
         version_variant = version_info[0][2].lower()
-
         if version_major == 8:
             version_variant = "mysql"
 
