@@ -3,10 +3,10 @@ from mysqld_integration_test.exceptions import InvalidLogLevel
 
 COLOR_OKBLUE = '\033[94m'
 COLOR_OKGREEN = '\033[92m'
-COLOR_WARNING = '\033[93m'
 COLOR_FAIL = '\033[91m'
 COLOR_ENDC = '\033[0m'
 
+
 class _Log():
     def __init__(self):
         logging.debug("magic")
@@ -25,10 +25,6 @@ class _Log():
         if self.logger:
             self.logger.error(_colored(msg, COLOR_FAIL))
 
-    def warn(self, msg):
-        if self.logger:
-            self.logger.warn(_colored(msg, COLOR_WARNING))
-
     def success(self, msg):
         if self.logger:
             self.logger.info(_colored(msg, COLOR_OKGREEN))
@@ -45,7 +41,9 @@ class _Log():
         else:
             raise InvalidLogLevel
 
+
 def _colored(msg, color):
     return f"{color}{msg}{COLOR_ENDC}"
 
+
 logger = _Log()
