@@ -1,15 +1,14 @@
 import os
 import functools
 import yaml
+import subprocess
 
-from mysqld_integration_test.version import __version__
 from mysqld_integration_test.helpers import Utils
 
-#ARGS_DATABASE = [ 'username', 'password', 'host', 'port', 'mysql_install_db_binary', 'mysqld_binary' ]
-#ARGS_GENERAL = [ 'timeout_start', 'timeout_stop', 'log_level', 'config_file']
 config_settings = {}
-config_settings['database'] = [ 'username', 'password', 'host', 'port', 'mysql_install_db_binary', 'mysqld_binary' ]
-config_settings['general'] = [ 'timeout_start', 'timeout_stop', 'log_level', 'config_file' ]
+config_settings['database'] = ['username', 'password', 'host', 'port', 'mysql_install_db_binary', 'mysqld_binary']
+config_settings['general'] = ['timeout_start', 'timeout_stop', 'log_level', 'config_file']
+
 
 def rgetattr(obj, attr, *args):
     def _getattr(obj, attr):
@@ -30,14 +29,21 @@ def merge_configs(config, section, section_cfg):
     return config
 
 
+def load_config_file(config_file):
+    if os.path.exists(config_file):
+        with open(config_file, "r", encoding='utf-8') as ymlfile:
+            cfg = yaml.load(ymlfile, Loader=yaml.FullLoader)
+        return cfg
+    return {}
+
+
 def parse_config(config, config_args):
     # See if there is a config file
-    if os.path.exists(config.general.config_file):
-        with open(config.general.config_file, "r", encoding='utf-8') as ymlfile:
-            cfg = yaml.load(ymlfile, Loader=yaml.FullLoader)
+    cfg = load_config_file(config.general.config_file)
 
-        # Merge config together with args
-        for section in config_settings:
+    # Merge config together with args
+    for section in config_settings:
+        if section in cfg:
             config = merge_configs(config, section, cfg[section])
 
     # Merge in any class arguments
@@ -66,8 +72,16 @@ class ConfigFile():
         self.database.password = 'root'
         self.database.socket_file = os.path.join(self.dirs.tmp_dir, 'mysql.sock')
         self.database.pid_file = os.path.join(self.dirs.tmp_dir, 'mysqld.pid')
-        self.database.mysqld_binary = Utils.find_program('mysqld', ['bin', 'libexec', 'sbin'])
-        self.database.mysql_install_db_binary = Utils.find_program('mysql_install_db', ['bin', 'scripts'])
+        self.database.mysqld_binary = Utils.find_program('mysqld')
+        self.database.mysql_install_db_binary = Utils.find_program('mysql_install_db')
+
+        # Get the mysql variant and version
+        (variant, version_major, version_minor) = Utils.parse_version(
+                subprocess.check_output([self.database.mysqld_binary, '--version']).decode("utf-8"))
+        self.version = ConfigAttribute()
+        self.version.variant = variant
+        self.version.major = version_major
+        self.version.minor = version_minor
 
         self.general = ConfigAttribute()
         self.general.timeout_start = 30
